@@ -19,19 +19,19 @@ def build_config() -> dict[str, str]:
         python_path=r"/usr/bin/python",
 
         # Package versions
-        contourpy_version="1.3.2",
-        meson_version="1.7.2",
-        mesonpy_version="0.17.1",
-        pybind11_version="2.13.6",
+        contourpy_version="1.3.3",
+        meson_version="1.8.2",
+        mesonpy_version="0.18.0",
+        pybind11_version="3.0.0",
 
         # Misc meson settings
         meson_backend="ninja",
-        build_dir=r"/build/python-contourpy/src/contourpy/.mesonpy-8tpkji3g/lib/contourpy/util",
+        build_dir=r"/build/python-contourpy/src/contourpy/.mesonpy-jisn2k94/lib/contourpy/util",
         source_dir=r"/build/python-contourpy/src/contourpy/lib/contourpy/util",
         cross_build="False",
 
         # Build options
-        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/build/python-contourpy/src/contourpy/.mesonpy-8tpkji3g/meson-python-native-file.ini",
+        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/build/python-contourpy/src/contourpy/.mesonpy-jisn2k94/meson-python-native-file.ini",
         buildtype="release",
         cpp_std="c++17",
         debug="False",
@@ -42,7 +42,7 @@ def build_config() -> dict[str, str]:
 
         # C++ compiler
         compiler_name="gcc",
-        compiler_version="14.2.1",
+        compiler_version="15.1.1",
         linker_id="ld.bfd",
         compile_command="c++",
 
